geowatch.cli.validate\_annotation\_schemas module
=================================================

.. automodule:: geowatch.cli.validate_annotation_schemas
   :members:
   :undoc-members:
   :show-inheritance:
